@@ -3,7 +3,7 @@ import logging
 from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr, dictinct_list
-from isc_common.auth.managers.base_user_manager import BaseUserManager
+from isc_common.auth.managers.base_user_manager import BaseUserManager, BaseUserQuerySet
 from isc_common.auth.models.usergroup import UserGroup
 from isc_common.bit import IsBitOn
 from isc_common.http.DSRequest import DSRequest
@@ -11,20 +11,95 @@ from isc_common.http.DSRequest import DSRequest
 logger = logging.getLogger(__name__)
 
 
+class UserQuerySet(BaseUserQuerySet):
+    pass
+
+
 class UserManager(BaseUserManager):
     use_in_migrations = True
 
+    def get_or_create(self, defaults=None, **kwargs):
+        from isc_common.auth.models.user import User
+
+        if defaults is None:
+            defaults = kwargs
+
+        username = kwargs.get('username')
+        if username is None:
+            username = defaults.get('username')
+        if username is None:
+            username = User.full_name(
+                first_name=defaults.get('first_name'),
+                last_name=defaults.get('last_name'),
+                middle_name=defaults.get('middle_name'),
+                birthday=defaults.get('birthday'),
+                translit=True,
+            )
+
+            if username is None:
+                raise Exception('username is None')
+
+        user = User.objects.getOptional(username=username)
+        if user is None:
+            description = defaults.get('description')
+
+            if description is not None and description.strip() == '':
+                description = None
+
+            setAttr(defaults, 'description', description)
+            user_data = self.get_user_data(**defaults)
+            try:
+                user = super().get(username=username)
+                return user, False
+
+            except User.DoesNotExist as ex:
+                setAttr(user_data, 'username', username)
+                user = super().create(**user_data)
+                user.set_password(username)
+                user.save()
+
+                return user, True
+
+
+        else:
+            return user, False
+
+    def update_or_create(self, defaults=None, **kwargs):
+        return super().update_or_create(defaults=defaults, **kwargs)
+
+    @classmethod
+    def get_user_data(cls, **kwargs):
+        last_name = kwargs.get('last_name')
+        first_name = kwargs.get('first_name')
+        middle_name = kwargs.get('middle_name')
+        description = kwargs.get('description')
+        birthday = kwargs.get('birthday')
+        # username = kwargs.get('username')
+
+        user_data = dict(
+            last_name=last_name.replace('ё', 'e').strip() if last_name else None,
+            first_name=first_name.replace('ё', 'e').strip() if first_name else None,
+            middle_name=middle_name.replace('ё', 'e').strip() if middle_name else None,
+            birthday=birthday if birthday else None,
+            description=description,
+            # username=username
+        )
+
+        return user_data
+
+    def get_queryset(self):
+        return UserQuerySet(self.model, using=self._db).filter(deleted_at=None)
+
     @classmethod
     def getRecord(cls, **kwargs):
         record = kwargs.get('record')
         res = {
-            'birtdate': record.birtdate,
+            'birthday': record.birthday,
             'bot': IsBitOn(record.props, 0),
             'color': record.color,
             'deliting': record.deliting,
             'description': record.description,
             'editing': record.editing,
-            'email': record.email,
             'first_name': record.first_name,
             'id': record.id,
             'last_login': record.last_login,
@@ -42,7 +117,7 @@ class UserManager(BaseUserManager):
     @classmethod
     def getRecord1(cls, record):
         res = {
-            'birtdate': record.birtdate,
+            'birthday': record.birthday,
             'bot': IsBitOn(record.props, 0),
             'color': record.color,
             'deliting': record.deliting,
