@@ -2,28 +2,29 @@ import logging
 
 from django.contrib.auth.validators import UnicodeUsernameValidator
 from django.core.mail import send_mail
-from django.db.models import EmailField, ManyToManyField, DateField
+from django.db.models import ManyToManyField, DateField
 from django.utils.translation import gettext_lazy as _
 
-from crypto.models.crypto_file import Crypto_file
 from isc_common.auth.models.abstract_base_user import AbstractBaseUser
 from isc_common.auth.models.usergroup import UserGroup
-from isc_common.fields.code_field import CodeField
+from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.name_field import NameField
+from isc_common.models.audit import AuditModel
 
 logger = logging.getLogger(__name__)
 
+class NonamedUserException(Exception):
+    pass
 
-class AbstractUser(AbstractBaseUser, Crypto_file):
+class AbstractUser(AbstractBaseUser, AuditModel):
     username_validator = UnicodeUsernameValidator()
 
-    birtdate = DateField(blank=True, null=True)
-    email = EmailField(verbose_name=_('E-mail'), blank=True, null=True)
+    username = CodeStrictField(verbose_name=_('логин'), unique=True, validators=[username_validator], error_messages={'unique': _("Такой пользователь уже существует."), }, )
     first_name = NameField(verbose_name=_('имя'))
     last_name = NameField(verbose_name=_('фамилия'))
     middle_name = NameField(verbose_name=_('отчетво'))
+    birthday = DateField(blank=True, null=True)
     usergroup = ManyToManyField(UserGroup, verbose_name=_('группы'))
-    username = CodeField(verbose_name=_('логин'), unique=True, validators=[username_validator], error_messages={'unique': _("Такой пользователь уже существует."), }, )
 
     @property
     def is_admin(self):
@@ -62,6 +63,41 @@ class AbstractUser(AbstractBaseUser, Crypto_file):
                f'{self.first_name.strip() if self.first_name else ""} ' \
                f'{self.middle_name.strip() if self.middle_name else ""}'
 
+    @classmethod
+    def full_name(cls, first_name, middle_name, last_name, birthday=None, translit=False):
+        if first_name is None and middle_name is None and last_name is None:
+            raise NonamedUserException('first_name is None and middle_name is None and last_name is None')
+
+        res = f'{last_name.strip()}' \
+              f'{first_name.strip() if first_name else ""} ' \
+              f'{middle_name.strip() if middle_name else ""} ' \
+              f'{birthday if birthday else ""}'
+        if translit is True:
+            return AuditModel.translit(res.strip())
+        return res.strip()
+
+    @classmethod
+    def short_name(cls, first_name, middle_name, last_name, translit=False):
+        if first_name is None and middle_name is None and last_name is None:
+            raise Exception('first_name is None and middle_name is None and last_name is None')
+
+        from isc_common.models.audit import AuditModel
+        fn = f'{first_name.strip()[0:1].upper() if first_name else ""}'
+        if fn != '':
+            fn = ' ' + fn + '.'
+
+        mn = f'{middle_name.strip()[0:1].upper() if middle_name else ""}'
+        if mn != '':
+            mn = ' ' + mn + '.'
+
+        if last_name is not None:
+            res = f'{last_name.strip()} {fn}{mn}'
+        else:
+            res = f'{fn}{mn}'
+        if translit is True:
+            return AuditModel.translit(res.strip())
+        return res.strip()
+
     @property
     def get_short_name(self):
         fn = f'{self.first_name.strip()[0:1].upper() if self.first_name else ""}'
