@@ -1,5 +1,4 @@
-from isc_common.auth.managers.user_manager import UserManager
-from isc_common.auth.models.user import User
+from isc_common.auth.models.user import User, UserManager
 from isc_common.auth.models.user_upload_photo import DSResponse_User_UploadPhoto
 from isc_common.auth.models.user_view import UserView
 from isc_common.http.DSRequest import DSRequest
