@@ -18,8 +18,8 @@ class Last_used_processesManager(AuditManager):
     def get_queryset(self):
         return Last_used_processesQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
         }
